@@ -1,7 +1,8 @@
 from .abstract_callback_stack import AbstractCallbackStack
 from .callback_stack import CallbackStack
 from ..utils.callback_stack_factory import CallbackStackFactory
-from ..data.loader import configurator, storages
+from ..data.config import configurator
+from ..data.loader import storages
 
 
 class AbbreviatedCallbackStack(AbstractCallbackStack):
